searchNodes=[{"doc":"Functions that work on graphs as an inductive data structure.","ref":"InductiveGraph.html","title":"InductiveGraph","type":"module"},{"doc":"Builds a graph from contexts.Examplesiex&gt; contexts = [{[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]}, {[{&quot;right&quot;, 1}], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]}, {[], 1, &quot;a&quot;, []}] iex&gt; {:ok, graph1} = InductiveGraph.build_graph(contexts) iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; {:ok, graph2} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.equal?(graph1, graph2) true","ref":"InductiveGraph.html#build_graph/1","title":"InductiveGraph.build_graph/1","type":"function"},{"doc":"Counts number of edges in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph |&gt; InductiveGraph.count_edges() 4","ref":"InductiveGraph.html#count_edges/1","title":"InductiveGraph.count_edges/1","type":"function"},{"doc":"Counts number of vertices in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, []) iex&gt; InductiveGraph.count_vertices(graph) 3","ref":"InductiveGraph.html#count_vertices/1","title":"InductiveGraph.count_vertices/1","type":"function"},{"doc":"Decomposes graph into an arbitrary context and the remaining graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.count_vertices(graph) 3 iex&gt; {:ok, _context, graph} = InductiveGraph.decompose(graph) iex&gt; InductiveGraph.count_vertices(graph) 2","ref":"InductiveGraph.html#decompose/1","title":"InductiveGraph.decompose/1","type":"function"},{"doc":"Decomposes graph into the context containing vertex and the remaining graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, context1, graph} = InductiveGraph.decompose(graph, 3) iex&gt; context1 {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]} iex&gt; {:ok, context2, graph} = InductiveGraph.decompose(graph, 2) iex&gt; context2 {[{&quot;right&quot;, 1}], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]} iex&gt; {:ok, context3, graph} = InductiveGraph.decompose(graph, 1) iex&gt; context3 {[], 1, &quot;a&quot;, []} iex&gt; InductiveGraph.empty?(graph) true","ref":"InductiveGraph.html#decompose/2","title":"InductiveGraph.decompose/2","type":"function"},{"doc":"Deletes edge from graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; edge = {1, 2} iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.delete_edge(graph, edge) iex&gt; InductiveGraph.pretty_print(graph) &lt;&gt; &quot;\\n&quot; ~s&#39;&#39;&#39; | {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]} &amp; {[], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]} &amp; {[], 1, &quot;a&quot;, []} &amp; Empty &#39;&#39;&#39;","ref":"InductiveGraph.html#delete_edge/2","title":"InductiveGraph.delete_edge/2","type":"function"},{"doc":"Deletes edges from graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; edges = [{1, 2}, {2, 1}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.delete_edges(graph, edges) iex&gt; InductiveGraph.pretty_print(graph) &lt;&gt; &quot;\\n&quot; ~s&#39;&#39;&#39; | {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]} &amp; {[], 2, &quot;b&quot;, []} &amp; {[], 1, &quot;a&quot;, []} &amp; Empty &#39;&#39;&#39;","ref":"InductiveGraph.html#delete_edges/2","title":"InductiveGraph.delete_edges/2","type":"function"},{"doc":"Deletes vertex from graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.delete_vertex(graph, 3) iex&gt; InductiveGraph.has_vertex?(graph, 3) false","ref":"InductiveGraph.html#delete_vertex/2","title":"InductiveGraph.delete_vertex/2","type":"function"},{"doc":"Deletes vertices from graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.delete_vertices(graph, [2, 3]) iex&gt; InductiveGraph.has_vertex?(graph, 3) false","ref":"InductiveGraph.html#delete_vertices/2","title":"InductiveGraph.delete_vertices/2","type":"function"},{"doc":"Determines if graph is empty.Examplesiex&gt; graph = InductiveGraph.empty_graph() iex&gt; InductiveGraph.empty?(graph) true iex&gt; {:ok, graph} = InductiveGraph.make_graph([{1, 1}], []) iex&gt; InductiveGraph.empty?(graph) false","ref":"InductiveGraph.html#empty?/1","title":"InductiveGraph.empty?/1","type":"function"},{"doc":"Creates an empty graph.Examplesiex&gt; graph = InductiveGraph.empty_graph() #InductiveGraph&lt;&gt; iex&gt; InductiveGraph.pretty_print(graph) &quot;| Empty&quot;","ref":"InductiveGraph.html#empty_graph/0","title":"InductiveGraph.empty_graph/0","type":"function"},{"doc":"Checks if two graphs are equal.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph1} = InductiveGraph.make_graph(tagged_vertices, []) iex&gt; {:ok, graph2} = InductiveGraph.insert_tagged_edges(graph1, tagged_edges) iex&gt; {:ok, graph3} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.equal?(graph1, graph2) false iex&gt; InductiveGraph.equal?(graph2, graph3) true","ref":"InductiveGraph.html#equal?/2","title":"InductiveGraph.equal?/2","type":"function"},{"doc":"Filters edges based on edge values that fails predicate in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; predicate = fn edge_value -&gt; String.length(edge_value) == 4 end iex&gt; graph = InductiveGraph.filter_edges(graph, predicate) iex&gt; InductiveGraph.pretty_print(graph) &lt;&gt; &quot;\\n&quot; ~s&#39;&#39;&#39; | {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, []} &amp; {[], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]} &amp; {[], 1, &quot;a&quot;, []} &amp; Empty &#39;&#39;&#39;","ref":"InductiveGraph.html#filter_edges/2","title":"InductiveGraph.filter_edges/2","type":"function"},{"doc":"Determines if edge is in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.has_edge?(graph, {1, 2}) true iex&gt; InductiveGraph.has_edge?(graph, {1, 3}) false","ref":"InductiveGraph.html#has_edge?/2","title":"InductiveGraph.has_edge?/2","type":"function"},{"doc":"Determines if vertex is in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; edges = [] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, edges) iex&gt; InductiveGraph.has_vertex?(graph, 3) true iex&gt; InductiveGraph.has_vertex?(graph, 4) false","ref":"InductiveGraph.html#has_vertex?/2","title":"InductiveGraph.has_vertex?/2","type":"function"},{"doc":"Inserts contexts into graph.Examplesiex&gt; graph1 = InductiveGraph.empty_graph() iex&gt; contexts = [{[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]}, {[{&quot;right&quot;, 1}], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]}, {[], 1, &quot;a&quot;, []}] iex&gt; {:ok, graph2} = InductiveGraph.insert_contexts(graph1, contexts) iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; {:ok, graph3} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.equal?(graph2, graph3) true","ref":"InductiveGraph.html#insert_contexts/2","title":"InductiveGraph.insert_contexts/2","type":"function"},{"doc":"Inserts tagged_edge into graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}] iex&gt; new_tagged_edge = {3, 1, &quot;up&quot;} iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.insert_tagged_edge(graph, new_tagged_edge) iex&gt; InductiveGraph.pretty_print(graph) &lt;&gt; &quot;\\n&quot; ~s&#39;&#39;&#39; | {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]} &amp; {[{&quot;right&quot;, 1}], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]} &amp; {[], 1, &quot;a&quot;, []} &amp; Empty &#39;&#39;&#39;","ref":"InductiveGraph.html#insert_tagged_edge/2","title":"InductiveGraph.insert_tagged_edge/2","type":"function"},{"doc":"Inserts tagged_edges into graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [] iex&gt; new_tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.insert_tagged_edges(graph, new_tagged_edges) iex&gt; InductiveGraph.pretty_print(graph) &lt;&gt; &quot;\\n&quot; ~s''' | {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]} &amp; {[{&quot;right&quot;, 1}], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]} &amp; {[], 1, &quot;a&quot;, []} &amp; Empty '''","ref":"InductiveGraph.html#insert_tagged_edges/2","title":"InductiveGraph.insert_tagged_edges/2","type":"function"},{"doc":"Inserts tagged_vertex into graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; new_tagged_vertex = {4, &quot;d&quot;} iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.insert_tagged_vertex(graph, new_tagged_vertex) iex&gt; {:ok, context, _graph} = InductiveGraph.decompose(graph, 4) iex&gt; context {[], 4, &quot;d&quot;, []}","ref":"InductiveGraph.html#insert_tagged_vertex/2","title":"InductiveGraph.insert_tagged_vertex/2","type":"function"},{"doc":"Inserts tagged_vertices into graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; new_tagged_vertices = [{4, &quot;d&quot;}, {5, &quot;e&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, graph} = InductiveGraph.insert_tagged_vertices(graph, new_tagged_vertices) iex&gt; InductiveGraph.pretty_print(graph, 2) &lt;&gt; &quot;\\n&quot; ~s&#39;&#39;&#39; | {[], 5, &quot;e&quot;, []} &amp; {[], 4, &quot;d&quot;, []} &amp; InductiveGraph &#39;&#39;&#39;","ref":"InductiveGraph.html#insert_tagged_vertices/2","title":"InductiveGraph.insert_tagged_vertices/2","type":"function"},{"doc":"Lists all tagged edges in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph |&gt; InductiveGraph.list_tagged_edges() |&gt; Enum.sort() [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}]","ref":"InductiveGraph.html#list_tagged_edges/1","title":"InductiveGraph.list_tagged_edges/1","type":"function"},{"doc":"Lists all tagged vertices in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, []) iex&gt; graph |&gt; InductiveGraph.list_tagged_vertices() |&gt; Enum.sort() [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}]","ref":"InductiveGraph.html#list_tagged_vertices/1","title":"InductiveGraph.list_tagged_vertices/1","type":"function"},{"doc":"Creates a graph from lists tagged_vertices and tagged_edges.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph |&gt; InductiveGraph.list_tagged_vertices() |&gt; Enum.sort() [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; graph |&gt; InductiveGraph.list_tagged_edges() |&gt; Enum.sort() [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}]","ref":"InductiveGraph.html#make_graph/2","title":"InductiveGraph.make_graph/2","type":"function"},{"doc":"Applies function to every edge value in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; function = &amp;String.reverse(&amp;1) iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph = InductiveGraph.map_edges(graph, function) iex&gt; {:ok, context, _graph} = InductiveGraph.decompose(graph, 3) iex&gt; context {[{&quot;nwod&quot;, 2}], 3, &quot;c&quot;, [{&quot;pu&quot;, 1}]}","ref":"InductiveGraph.html#map_edges/2","title":"InductiveGraph.map_edges/2","type":"function"},{"doc":"Applies function to every context in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; function = fn context = {_p, _v, value, _s} -&gt; put_elem(context, 2, String.duplicate(value, 5)) end iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph = InductiveGraph.map_graph(graph, function) iex&gt; {:ok, context, _graph} = InductiveGraph.decompose(graph, 3) iex&gt; context {[{&quot;down&quot;, 2}], 3, &quot;ccccc&quot;, [{&quot;up&quot;, 1}]}","ref":"InductiveGraph.html#map_graph/2","title":"InductiveGraph.map_graph/2","type":"function"},{"doc":"Applies function to every vertex value in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; function = &amp;String.duplicate(&amp;1, 5) iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph = InductiveGraph.map_vertices(graph, function) iex&gt; {:ok, context, _graph} = InductiveGraph.decompose(graph, 3) iex&gt; context {[{&quot;down&quot;, 2}], 3, &quot;ccccc&quot;, [{&quot;up&quot;, 1}]}","ref":"InductiveGraph.html#map_vertices/2","title":"InductiveGraph.map_vertices/2","type":"function"},{"doc":"Applies vertex_function to every vertex value and edge_function to every edge value in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; vertex_function = &amp;String.duplicate(&amp;1, 5) iex&gt; edge_function = &amp;String.reverse(&amp;1) iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; graph = InductiveGraph.map_vertices_and_edges(graph, vertex_function, edge_function) iex&gt; {:ok, context, _graph} = InductiveGraph.decompose(graph, 3) iex&gt; context {[{&quot;nwod&quot;, 2}], 3, &quot;ccccc&quot;, [{&quot;pu&quot;, 1}]}","ref":"InductiveGraph.html#map_vertices_and_edges/3","title":"InductiveGraph.map_vertices_and_edges/3","type":"function"},{"doc":"Merges context into graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph1} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; {:ok, context, graph2} = InductiveGraph.decompose(graph1, 3) iex&gt; {:ok, graph3} = InductiveGraph.merge(graph2, context) iex&gt; InductiveGraph.equal?(graph1, graph3) true","ref":"InductiveGraph.html#merge/2","title":"InductiveGraph.merge/2","type":"function"},{"doc":"Pretty prints inductive representation of graph.If count is provided, then up to count number of contexts will be shown.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.pretty_print(graph) &lt;&gt; &quot;\\n&quot; ~s&#39;&#39;&#39; | {[{&quot;down&quot;, 2}], 3, &quot;c&quot;, [{&quot;up&quot;, 1}]} &amp; {[{&quot;right&quot;, 1}], 2, &quot;b&quot;, [{&quot;left&quot;, 1}]} &amp; {[], 1, &quot;a&quot;, []} &amp; Empty &#39;&#39;&#39;","ref":"InductiveGraph.html#pretty_print/2","title":"InductiveGraph.pretty_print/2","type":"function"},{"doc":"Folds function over graph with starting value accumulator.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; tagged_edges = [{1, 2, &quot;right&quot;}, {2, 1, &quot;left&quot;}, {2, 3, &quot;down&quot;}, {3, 1, &quot;up&quot;}] iex&gt; function = fn {_p, vertex, _v, _s}, result -&gt; vertex + result end iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, tagged_edges) iex&gt; InductiveGraph.unordered_fold(graph, 0, function) 6","ref":"InductiveGraph.html#unordered_fold/3","title":"InductiveGraph.unordered_fold/3","type":"function"},{"doc":"Gets range of vertex values in graph.Examplesiex&gt; tagged_vertices = [{1, &quot;a&quot;}, {2, &quot;b&quot;}, {3, &quot;c&quot;}] iex&gt; {:ok, graph} = InductiveGraph.make_graph(tagged_vertices, []) iex&gt; InductiveGraph.vertex_range(graph) {:ok, 1, 3}","ref":"InductiveGraph.html#vertex_range/1","title":"InductiveGraph.vertex_range/1","type":"function"},{"doc":"","ref":"InductiveGraph.html#t:adjacents/0","title":"InductiveGraph.adjacents/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:context/0","title":"InductiveGraph.context/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:edge/0","title":"InductiveGraph.edge/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:edge_value/0","title":"InductiveGraph.edge_value/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:neighbor/0","title":"InductiveGraph.neighbor/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:predecessors/0","title":"InductiveGraph.predecessors/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:successors/0","title":"InductiveGraph.successors/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:t/0","title":"InductiveGraph.t/0","type":"opaque"},{"doc":"","ref":"InductiveGraph.html#t:tagged_edge/0","title":"InductiveGraph.tagged_edge/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:tagged_vertex/0","title":"InductiveGraph.tagged_vertex/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:value/0","title":"InductiveGraph.value/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:vertex/0","title":"InductiveGraph.vertex/0","type":"type"},{"doc":"","ref":"InductiveGraph.html#t:vertex_value/0","title":"InductiveGraph.vertex_value/0","type":"type"},{"doc":"Functions to manage internal representation of inductive graph.","ref":"InductiveGraph.Internal.html","title":"InductiveGraph.Internal","type":"module"},{"doc":"Adds edge_values with neighbor to adjacents.","ref":"InductiveGraph.Internal.html#add_edges_to_adjacents/3","title":"InductiveGraph.Internal.add_edges_to_adjacents/3","type":"function"},{"doc":"Adds edge_values with neighbor to either predecessor or successor adjacents position in context.","ref":"InductiveGraph.Internal.html#add_edges_to_context/4","title":"InductiveGraph.Internal.add_edges_to_context/4","type":"function"},{"doc":"Counts number of vertices in graph.","ref":"InductiveGraph.Internal.html#count_vertices/1","title":"InductiveGraph.Internal.count_vertices/1","type":"function"},{"doc":"Decomposes graph into the context containing vertex and the remaining graph.","ref":"InductiveGraph.Internal.html#decompose/2","title":"InductiveGraph.Internal.decompose/2","type":"function"},{"doc":"Determines if graph is empty.","ref":"InductiveGraph.Internal.html#empty?/1","title":"InductiveGraph.Internal.empty?/1","type":"function"},{"doc":"Creates an empty graph.","ref":"InductiveGraph.Internal.html#empty_graph/0","title":"InductiveGraph.Internal.empty_graph/0","type":"function"},{"doc":"Converts adjacents to [{edge_value, neighbor}].","ref":"InductiveGraph.Internal.html#from_adjacents/1","title":"InductiveGraph.Internal.from_adjacents/1","type":"function"},{"doc":"Converts context to {[{edge_value, neighbor}], vertex, vertex_value, [{edge_value, neighbor}]}.","ref":"InductiveGraph.Internal.html#from_context/2","title":"InductiveGraph.Internal.from_context/2","type":"function"},{"doc":"Determines if edge is in graph.","ref":"InductiveGraph.Internal.html#has_edge?/2","title":"InductiveGraph.Internal.has_edge?/2","type":"function"},{"doc":"Determines if vertex is in graph.","ref":"InductiveGraph.Internal.html#has_vertex?/2","title":"InductiveGraph.Internal.has_vertex?/2","type":"function"},{"doc":"Inserts tagged_edge into graph.","ref":"InductiveGraph.Internal.html#insert_tagged_edge/2","title":"InductiveGraph.Internal.insert_tagged_edge/2","type":"function"},{"doc":"Inserts tagged_edges into graph.","ref":"InductiveGraph.Internal.html#insert_tagged_edges/2","title":"InductiveGraph.Internal.insert_tagged_edges/2","type":"function"},{"doc":"Inserts tagged_vertex into graph.","ref":"InductiveGraph.Internal.html#insert_tagged_vertex/2","title":"InductiveGraph.Internal.insert_tagged_vertex/2","type":"function"},{"doc":"Inserts tagged_vertices into graph.","ref":"InductiveGraph.Internal.html#insert_tagged_vertices/2","title":"InductiveGraph.Internal.insert_tagged_vertices/2","type":"function"},{"doc":"Lists all tagged edges in graph.","ref":"InductiveGraph.Internal.html#list_tagged_edges/1","title":"InductiveGraph.Internal.list_tagged_edges/1","type":"function"},{"doc":"Lists all vertices in graph.","ref":"InductiveGraph.Internal.html#list_tagged_vertices/1","title":"InductiveGraph.Internal.list_tagged_vertices/1","type":"function"},{"doc":"Creates a graph from tagged_vertices and tagged_edges.","ref":"InductiveGraph.Internal.html#make_graph/2","title":"InductiveGraph.Internal.make_graph/2","type":"function"},{"doc":"Applies function to adjacents.","ref":"InductiveGraph.Internal.html#map_adjacents/2","title":"InductiveGraph.Internal.map_adjacents/2","type":"function"},{"doc":"Applies function to every edge value in graph.","ref":"InductiveGraph.Internal.html#map_edges/2","title":"InductiveGraph.Internal.map_edges/2","type":"function"},{"doc":"Applies function to every context in graph.","ref":"InductiveGraph.Internal.html#map_graph/2","title":"InductiveGraph.Internal.map_graph/2","type":"function"},{"doc":"Applies function to every vertex value in graph.","ref":"InductiveGraph.Internal.html#map_vertices/2","title":"InductiveGraph.Internal.map_vertices/2","type":"function"},{"doc":"Applies vertex_function to every vertex value and edge_function to every edge value in graph.","ref":"InductiveGraph.Internal.html#map_vertices_and_edges/3","title":"InductiveGraph.Internal.map_vertices_and_edges/3","type":"function"},{"doc":"Merges context into graph.","ref":"InductiveGraph.Internal.html#merge/2","title":"InductiveGraph.Internal.merge/2","type":"function"},{"doc":"Creates a new context based on vertex_value.","ref":"InductiveGraph.Internal.html#new_context/1","title":"InductiveGraph.Internal.new_context/1","type":"function"},{"doc":"Pretty prints inductive representation of graph.If count is provided, then up to count number of contexts will be shown.","ref":"InductiveGraph.Internal.html#pretty_print/2","title":"InductiveGraph.Internal.pretty_print/2","type":"function"},{"doc":"Removes edges with neighbor from either predecessor or successor adjacents position in contexts of vertices.","ref":"InductiveGraph.Internal.html#prune_adjacents/4","title":"InductiveGraph.Internal.prune_adjacents/4","type":"function"},{"doc":"Removes edges with neighbor from either predecessor or successor adjacents position in context.","ref":"InductiveGraph.Internal.html#remove_edges_from_context/3","title":"InductiveGraph.Internal.remove_edges_from_context/3","type":"function"},{"doc":"Converts [{edge_value, neighbor}] to adjacents.","ref":"InductiveGraph.Internal.html#to_adjacents/1","title":"InductiveGraph.Internal.to_adjacents/1","type":"function"},{"doc":"Converts {[{edge_value, neighbor}], vertex, vertex_value, [{edge_value, neighbor}]} to context.","ref":"InductiveGraph.Internal.html#to_context/1","title":"InductiveGraph.Internal.to_context/1","type":"function"},{"doc":"Updates context by function based on update_type.","ref":"InductiveGraph.Internal.html#update_context/3","title":"InductiveGraph.Internal.update_context/3","type":"function"},{"doc":"Gets range of vertex in graph.Returns {:ok, minimum, maximum} for graphs with at least one vertex. Returns :error for empty graph.","ref":"InductiveGraph.Internal.html#vertex_range/1","title":"InductiveGraph.Internal.vertex_range/1","type":"function"},{"doc":"","ref":"InductiveGraph.Internal.html#t:adjacents/0","title":"InductiveGraph.Internal.adjacents/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:context/0","title":"InductiveGraph.Internal.context/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:edge/0","title":"InductiveGraph.Internal.edge/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:edge_value/0","title":"InductiveGraph.Internal.edge_value/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:neighbor/0","title":"InductiveGraph.Internal.neighbor/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:predecessors/0","title":"InductiveGraph.Internal.predecessors/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:successors/0","title":"InductiveGraph.Internal.successors/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:t/0","title":"InductiveGraph.Internal.t/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:tagged_edge/0","title":"InductiveGraph.Internal.tagged_edge/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:tagged_vertex/0","title":"InductiveGraph.Internal.tagged_vertex/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:value/0","title":"InductiveGraph.Internal.value/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:vertex/0","title":"InductiveGraph.Internal.vertex/0","type":"type"},{"doc":"","ref":"InductiveGraph.Internal.html#t:vertex_value/0","title":"InductiveGraph.Internal.vertex_value/0","type":"type"},{"doc":"Functions for use by other modules.","ref":"InductiveGraph.Utilities.html","title":"InductiveGraph.Utilities","type":"module"},{"doc":"Updates value at key in map by function.If key is present in map with value value, then {:ok, new_map} is returned where new_map is equivalent map with the result of function with argument value as the new value for key. Otherwise, :error is returned.","ref":"InductiveGraph.Utilities.html#map_update/3","title":"InductiveGraph.Utilities.map_update/3","type":"function"},{"doc":"Updates element at position in tuple by function.","ref":"InductiveGraph.Utilities.html#tuple_update_position!/3","title":"InductiveGraph.Utilities.tuple_update_position!/3","type":"function"},{"doc":"InductiveGraphInductive graph library implemented in Elixir.This library is a port of the Haskell Functional Graph Library based on Martin Erwig's Paper.","ref":"readme.html","title":"InductiveGraph","type":"extras"},{"doc":"Master branch currently provides functions for construction, destruction, update, conversion, and inspection of inductive graphs.Other branches in the repository are have samples of dfs and bfs implementations and maximum flow.","ref":"readme.html#development-status","title":"InductiveGraph - Development Status","type":"extras"}]